#
# spec file for package python-pydot
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-pydot
Version:        1.2.4
Release:        lp151.2.2
Url:            https://github.com/erocarrera/pydot
Summary:        Create (dot) graphs from python
License:        MIT
Group:          Development/Libraries/Python
Source:         https://files.pythonhosted.org/packages/source/p/pydot/pydot-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pyparsing >= 2.1.4}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       graphviz
Requires:       python-pyparsing >= 2.1.4
BuildArch:      noarch
%python_subpackages

%description
pydot allows to easily create both directed and non directed graphs from Python. 
Currently all attributes implemented in the Dot language are supported (up to Graphviz 2.16).

%prep
%setup -q -n pydot-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%files %{python_files}
%defattr(-,root,root,-)
%doc README.md LICENSE
%{python_sitelib}/dot_parser.py*
%{python_sitelib}/pydot.py*
%pycache_only %{python_sitelib}/__pycache__/dot_parser.*.py*
%pycache_only %{python_sitelib}/__pycache__/pydot.*.py*
%{python_sitelib}/pydot-%{version}-py*.egg-info

%changelog
* Sat Jan  6 2018 arun@gmx.de
- specfile:
  * update copyright year
- update to version 1.2.4:
  * ENH: propagate `LD_LIBRARY_PATH` when calling GraphViz
  * API: raise `OSError` when a GraphViz executable is not found
  * API: add method `__str__` to classes `Node, Edge, Graph`
  * API: add arg `encoding` to `Dot` methods `create, write`
  * API: quote cluster names when necessary
  * API: give source and destination nodes as separate args to
    `Edge.__init__`
  * API: never ignore `src, dst`, overwrite if `points` defined in
    `obj_dict`
* Wed Apr 19 2017 toddrme2178@gmail.com
- Implement single-spec version.
* Tue Nov  1 2016 toddrme2178@gmail.com
- Update source url
- Remove some obsolete parts of the spec file
* Tue Nov  1 2016 toddrme2178@gmail.com
- Update to 1.2.3
  - support Python 2.6
  - several corrections
  - quote empty strings to avoid graphviz errors
- Update to 1.2.0
  - support Python 3
  - bumped dependency to `pyparsing >= 2.1.4`
  - tests running on Travis CI
  - tests require `chardet`
  - detect character encoding for most test files
    using the package `chardet`
  - API:
    + on all operating systems, search GraphViz
    executables in environment `$PATH`,
    using `subprocess.Popen`.
    No paths hard-coded due to security and privacy issues.
    + add option to pass GraphViz executable name
    or absolute path as `prog` to `pydot.Dot.write_*` methods.
    This provides an alternative to
    adding GraphViz to the `$PATH`.
    + the functions:
  * `pydot.graph_from_dot_data`
  * `pydot.graph_from_dot_file`
  * `dot_parser.parse_dot_data`
    changed to always return a `list` of graphs,
    instead of behaving differently for singletons.
    + require that the user explicitly give an encoding to
    the function `pydot.graph_from_dot_file`,
    with default encoding same as `io.open`.
    + decode to unicode at program boundaries, and
    treat binary images as bytes,
    for more compatibility with python 3.
    Use `io.open`, instead of the built-in `open`.
    + rm function `pydot.set_graphviz_executables`
    + rm attribute `pydot.Dot.progs`
- Update to 1.1.0
  - compatibility with `pyparsing >= 1.5.7`
  - API:
    + `pydot.Graph.to_string`: hide `subgraph` keyword only if so requested
    + produce `warnings.warn` if `pydot.dot_parser` fails to import,
    instead of `print`
- Update to 1.0.29
  - Maintenance release that keeps the same API
  - pin `pyparsing == 1.5.7`
  - update version number in source code
  - update `setup.py`
- Remove unneeded python-pydot-1.0.28_fix_pyparser_2_incompatibility.patch
- Remove out-of-date example files
* Sat May  3 2014 andrea@opensuse.org
- added python-pydot-1.0.28_fix_pyparser_2_incompatibility.patch to fix
  incompatibility when using pydot with pyparser 2
* Fri May 25 2012 toddrme2178@gmail.com
- Update to version 1.0.28
  * Bugfixes
- Spec file cleanup
* Wed Jun  1 2011 saschpe@suse.de
- Update to version 1.0.25
  * Minor bugfixes
- Spec file cleanup:
  * Package examples as 'examples'
  * Use SUSE version checks for %%py_requires and noarch
* Thu Feb 17 2011 jw@novell.com
- Update to 1.0.4
- Example-demo.py added.
* Thu Feb 17 2011 jw@novell.com
- Taken from home:leo_eraly
